@@ -1,13 +1,13 @@
 package App::DumpPERLANCARSampleTree;
 
-our $DATE = '2016-04-01'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2016-04-07'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
-use PERLANCAR::Tree::Examples qw(gen_sample_tree);
+use PERLANCAR::Tree::Examples qw(gen_sample_data);
 
 our %SPEC;
 
@@ -16,12 +16,12 @@ $SPEC{dump_perlancar_sample_tree} = {
     summary => 'Dump tree from PERLANCAR::Tree::Examples',
     args => {
         size => {
-            schema => $PERLANCAR::Tree::Examples::SPEC{gen_sample_tree}{args}{size}{schema},
+            schema => $PERLANCAR::Tree::Examples::SPEC{gen_sample_data}{args}{size}{schema},
             req => 1,
             pos => 0,
         },
         backend => {
-            schema => $PERLANCAR::Tree::Examples::SPEC{gen_sample_tree}{args}{backend}{schema},
+            schema => $PERLANCAR::Tree::Examples::SPEC{gen_sample_data}{args}{backend}{schema},
         },
     },
     result_naked => 1,
@@ -32,7 +32,7 @@ sub dump_perlancar_sample_tree {
 
     my %args = @_;
 
-    Tree::Dump::tdmp(gen_sample_tree(
+    Tree::Dump::tdmp(gen_sample_data(
         size => $args{size},
         backend => $args{backend},
     ));
@@ -53,7 +53,7 @@ App::DumpPERLANCARSampleTree - Dump tree from PERLANCAR::Tree::Examples
 
 =head1 VERSION
 
-This document describes version 0.002 of App::DumpPERLANCARSampleTree (from Perl distribution App-DumpPERLANCARSampleTree), released on 2016-04-01.
+This document describes version 0.003 of App::DumpPERLANCARSampleTree (from Perl distribution App-DumpPERLANCARSampleTree), released on 2016-04-07.
 
 =head1 FUNCTIONS
 
